@@ -1,14 +1,23 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
 from __future__ import annotations
+
 from copy import copy
 from typing import List, Optional, Union
+
 import scipp as sc
-from .nxobject import NXobject, Field, ScippIndex, NexusStructureError
-from .nxobject import is_dataset, asarray
+
 from .nxdata import NXdata, NXdataStrategy
 from .nxevent_data import NXevent_data
+from .nxobject import (
+    Field,
+    NexusStructureError,
+    NXobject,
+    ScippIndex,
+    asarray,
+    is_dataset,
+)
 
 
 class NXdetectorStrategy(NXdataStrategy):
@@ -137,7 +146,8 @@ class NXdetector(NXobject):
         super().__init__(*args, **kwargs)
         self._event_select = tuple()
         self._nxevent_data_fields = [
-            'event_time_zero', 'event_index', 'event_time_offset', 'event_id'
+            'event_time_zero', 'event_index', 'event_time_offset', 'event_id',
+            'cue_timestamp_zero', 'cue_index', 'pulse_height'
         ]
         self._detector_number_fields = ['detector_number', 'pixel_id', 'spectrum_index']
 
