@@ -1,23 +1,28 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
 from __future__ import annotations
-import re
-import inspect
-import warnings
+
 import datetime
-import dateutil.parser
 import functools
-from typing import overload, List, Union, Any, Dict, Tuple, Protocol, Optional, Callable
+import inspect
+import re
+import warnings
+from typing import Any, Callable, Dict, List, Optional, Protocol, Tuple, Union, overload
+
+import dateutil.parser
+import h5py
 import numpy as np
 import scipp as sc
-import h5py
 
-from ._hdf5_nexus import _cset_to_encoding, _ensure_str
-from ._hdf5_nexus import _ensure_supported_int_type, _warn_latin1_decode
-from .typing import H5Group, H5Dataset, ScippIndex
-from ._common import to_plain_index
-from ._common import convert_time_to_datetime64
+from ._common import convert_time_to_datetime64, to_plain_index
+from ._hdf5_nexus import (
+    _cset_to_encoding,
+    _ensure_str,
+    _ensure_supported_int_type,
+    _warn_latin1_decode,
+)
+from .typing import H5Dataset, H5Group, ScippIndex
 
 NXobjectIndex = Union[str, ScippIndex]
 
@@ -139,7 +144,7 @@ class Field:
     """
 
     def __init__(self, dataset: H5Dataset, *, ancestor, dims=None, is_time=None):
-        self._ancestor = ancestor  # Ususally the parent, but may be grandparent, etc.
+        self._ancestor = ancestor  # Usually the parent, but may be grandparent, etc.
         self._dataset = dataset
         self._shape = self._dataset.shape
         self._is_time = is_time
@@ -281,6 +286,10 @@ class Field:
     def dims(self) -> List[str]:
         return self._dims
 
+    @property
+    def sizes(self) -> Dict[str, int]:
+        return dict(zip(self.dims, self.shape))
+
     @property
     def unit(self) -> Union[sc.Unit, None]:
         if (unit := self.attrs.get('units')) is not None:
@@ -302,6 +311,14 @@ def is_dataset(obj: Union[H5Group, H5Dataset]) -> bool:
     return hasattr(obj, 'shape')
 
 
+class NXobjectStrategy:
+
+    @staticmethod
+    def include_child(_) -> bool:
+        """Return True if the child should be included when loading."""
+        return True
+
+
 class NXobject:
     """Base class for all NeXus groups.
     """
@@ -315,11 +332,10 @@ class NXobject:
         # TODO can strategies replace child-params?
         self.child_params = {}
         self._definition = definition
-        if strategy is not None:
-            self._strategy = strategy
-        elif self._definition is not None:
+        self._strategy = strategy
+        if strategy is None and self._definition is not None:
             self._strategy = self._definition.make_strategy(self)
-        else:
+        if self._strategy is None:
             self._strategy = self._default_strategy()
 
     def _default_strategy(self):
@@ -327,7 +343,7 @@ class NXobject:
         Default strategy to use when none given and when the application definition
         does not provide one. Override in child classes to set a default.
         """
-        return None
+        return NXobjectStrategy
 
     def _make(self, group) -> NXobject:
         if (nx_class := Attrs(group.attrs).get('NX_class')) is not None:
@@ -353,13 +369,37 @@ class NXobject:
                              **self.child_params.get(name, {}))
             else:
                 return self._make(item)
-        da = self._getitem(name)
-        if (t := self.depends_on) is not None:
-            if isinstance(da, dict):
-                da['depends_on'] = t
+        try:
+            da = self._getitem(name)
+        except Exception as e:
+            # If the child class cannot load this group, we fall back to returning the
+            # underlying datasets in a DataGroup.
+            if type(self)._getitem == NXobject._getitem:
+                raise
             else:
-                da.coords['depends_on'] = t if isinstance(t,
-                                                          sc.Variable) else sc.scalar(t)
+                warnings.warn(
+                    f"Failed to load {self.name} as {type(self).__name__}:\n{e}\n"
+                    "Falling back to loading HDF5 group children as scipp.DataGroup.")
+            da = NXobject._getitem(self, name)
+        if (t := self.depends_on) is not None:
+
+            def insert(name, obj):
+                if hasattr(da, 'coords'):
+                    da.coords[name] = obj if isinstance(obj,
+                                                        sc.Variable) else sc.scalar(obj)
+                else:
+                    da[name] = obj
+
+            insert('depends_on', t)
+            # If loading the transformation failed, 'depends_on' returns a string, the
+            # path to the transformation. If this is a nested group, we load it here.
+            # Note that this info is currently incomplete, since attributes are not
+            # loaded.
+            if isinstance(t, str):
+                from .nexus_classes import NXtransformations
+                for name, group in self[NXtransformations].items():
+                    insert(name, group[()])
+
         return da
 
     def _get_children_by_nx_class(
@@ -378,7 +418,7 @@ class NXobject:
         ...
 
     @overload
-    def __getitem__(self, name: ScippIndex) -> Union[sc.DataArray, sc.Dataset]:
+    def __getitem__(self, name: ScippIndex) -> Union[sc.DataArray, sc.DataGroup]:
         ...
 
     @overload
@@ -398,7 +438,7 @@ class NXobject:
           classes. ``Field`` selects all child fields, i.e., all datasets but not
           groups.
         - Scipp-style index: Load the specified slice of the current group, returning
-          a :class:`scipp.DataArray` or :class:`scipp.Dataset`.
+          a :class:`scipp.DataArray` or :class:`scipp.DataGroup`.
 
         Parameters
         ----------
@@ -419,8 +459,11 @@ class NXobject:
             return self._get_children_by_nx_class(name)
         return self._get_child(name, use_field_dims=True)
 
-    def _getitem(self, index: ScippIndex) -> Union[sc.DataArray, sc.Dataset]:
-        raise NotImplementedError(f'Loading {self.nx_class} is not supported.')
+    def _getitem(self, index: ScippIndex) -> Union[sc.DataArray, sc.DataGroup]:
+        include = getattr(self._strategy, 'include_child', lambda x: True)
+        return sc.DataGroup(
+            {name: child[index]
+             for name, child in self.items() if include(child)})
 
     def _get_field_dims(self, name: str) -> Union[None, List[str]]:
         """Subclasses should reimplement this to provide dimension labels for fields."""
@@ -478,8 +521,14 @@ class NXobject:
     def depends_on(self) -> Union[sc.Variable, sc.DataArray, None]:
         if (depends_on := self.get('depends_on')) is not None:
             # Imported late to avoid cyclic import
-            from .nxtransformations import get_full_transformation
-            return get_full_transformation(depends_on)
+            from .nxtransformations import TransformationError, get_full_transformation
+            try:
+                return get_full_transformation(depends_on)
+            except TransformationError as e:
+                warnings.warn(
+                    f"Failed to load transformation {self.name}/{depends_on}:\n{e}\n"
+                    "Falling back to returning the path to the transformation.")
+                return depends_on[()]
         return None
 
     def __repr__(self) -> str:
@@ -546,7 +595,7 @@ class NXobject:
         nxclasses = []
         # Avoiding self.values() since it is more costly, but mainly since there may be
         # edge cases where creation of Field/NXobject may raise on unrelated children.
-        for name, val in self._group.items():
+        for _, val in self._group.items():
             if not is_dataset(val):
                 nxclasses.append(self._make(val).nx_class)
         for key in set(nxclasses):
