@@ -1,14 +1,17 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
-import numpy as np
 from typing import Union
+
+import numpy as np
 import scipp as sc
 import scipp.spatial
+
 try:
     from scipp.scipy import interpolate
 except ImportError:  # scipp<22.11
     from scipp import interpolate
+
 from .nxobject import Field, NXobject, ScippIndex
 
 
@@ -62,7 +65,10 @@ class Transformation:
         # According to private communication with Tobias Richter, NeXus allows 0-D or
         # shape=[1] for single values. It is unclear how and if this could be
         # distinguished from a scan of length 1.
-        t = self._obj[select] * self.vector
+        value = self._obj[select]
+        if isinstance(value, sc.DataGroup):
+            raise TransformationError(f"Failed to load transformation at {self.name}.")
+        t = value * self.vector
         v = t if isinstance(t, sc.Variable) else t.data
         if transformation_type == 'translation':
             v = v.to(unit='m', copy=False)
