@@ -1,9 +1,9 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright (c) 2022 Scipp contributors (https://github.com/scipp)
+# Copyright (c) 2023 Scipp contributors (https://github.com/scipp)
 # @author Simon Heybrock
 from __future__ import annotations
-from typing import Any, Protocol, Union, Tuple, Dict, List, Callable
-from typing import TYPE_CHECKING
+
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Protocol, Tuple, Union
 
 
 class H5Base(Protocol):
