@@ -1,8 +1,9 @@
 import h5py
 import numpy as np
-import scipp as sc
-from scippnexus import NXroot, NXentry, NXdetector, NXevent_data, NexusStructureError
 import pytest
+import scipp as sc
+
+from scippnexus import NexusStructureError, NXdetector, NXentry, NXevent_data, NXroot
 
 
 @pytest.fixture()
@@ -14,12 +15,13 @@ def nxroot(request):
         yield root
 
 
-def test_raises_if_no_data_found(nxroot):
+def test_warns_if_no_data_found(nxroot):
     detector_numbers = sc.array(dims=[''], unit=None, values=np.array([1, 2, 3, 4]))
     detector = nxroot.create_class('detector0', NXdetector)
     detector.create_field('detector_numbers', detector_numbers)
-    with pytest.raises(NexusStructureError):
-        detector[...]
+    with pytest.warns(UserWarning, match="Failed to load "):
+        dg = detector[...]
+    assert isinstance(dg, sc.DataGroup)
 
 
 def test_can_load_fields_if_no_data_found(nxroot):
@@ -52,7 +54,9 @@ def test_loads_events_when_data_and_events_found(nxroot):
                                                         values=[1]))
     detector.create_field('event_time_zero', sc.array(dims=[''], unit='s', values=[1]))
     detector.create_field('event_index', sc.array(dims=[''], unit='None', values=[0]))
-    assert detector[...].bins is not None
+    loaded = detector[...]
+    assert loaded.bins is not None
+    assert loaded.values[0].variances is None
 
 
 def detector_numbers_xx_yy_1234():
@@ -252,7 +256,7 @@ def test_loading_event_data_with_selection_and_automatic_detector_numbers_raises
     detector = nxroot.create_class('detector0', NXdetector)
     create_event_data_ids_1234(detector.create_class('events', NXevent_data))
     assert detector.dims == ['detector_number']
-    with pytest.raises(NexusStructureError):
+    with pytest.raises(ValueError):
         detector['detector_number', 0]
 
 
